from django.db import models

class Country(models.Model):
	name = models.CharField(max_length = 100, db_index = True)
	code = models.CharField(max_length = 2, unique = True)
	
	def __unicode__(self):
		return self.name
	
	class Meta:
		ordering = ('name',)


# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Country'
        db.create_table('international_country', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('code', self.gf('django.db.models.fields.CharField')(unique=True, max_length=2)),
        ))
        db.send_create_signal('international', ['Country'])


    def backwards(self, orm):
        # Deleting model 'Country'
        db.delete_table('international_country')


    models = {
        'international.country': {
            'Meta': {'ordering': "('name',)", 'object_name': 'Country'},
            'code': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '2'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['international']


#!/usr/bin/env python
from distutils.core import setup

setup(
	name = 'bambu-international',
	version = '0.0.1',
	description = 'Provides a list of countries and a helper function to retrieve the Country object from a user\'s IP address',
	author = 'Steadman',
	author_email = 'mark@steadman.io',
	url = 'http://pypi.python.org/pypi/bambu-international',
	install_requires = [
		'Django>=1.4',
		'pygeoip'
	],
	packages = [
		'bambu',
		'bambu.international',
		'bambu.international.migrations'
	],
	package_data = {
		'bambu.international': [
			'fixtures/*.json',
			'fixtures/*.dat',
			'fixtures/*.txt'
		]
	},
	classifiers = [
		'Development Status :: 4 - Beta',
		'Environment :: Web Environment',
		'Framework :: Django'
	]
)


from bambu.international.models import Country
from pygeoip import GeoIP, MEMORY_CACHE
from os import path
import threading, socket

__version__ = '0.0.1'

def ip_to_country(ip_address):
	db = GeoIP(
		path.abspath(
			path.join(
				path.dirname(__file__),
				'fixtures',
				'geoip.dat'
			)
		),
		MEMORY_CACHE
	)
	
	return Country.objects.get(
		code = db.country_code_by_addr(ip_address)
	)

def domain_to_country(domain):
	ip_address = socket.gethostbyname(domain)
	return ip_to_country(ip_address)


# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding index on 'Country', fields ['name']
        db.create_index('international_country', ['name'])


    def backwards(self, orm):
        # Removing index on 'Country', fields ['name']
        db.delete_index('international_country', ['name'])


    models = {
        'international.country': {
            'Meta': {'ordering': "('name',)", 'object_name': 'Country'},
            'code': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '2'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100', 'db_index': 'True'})
        }
    }

    complete_apps = ['international']